@@ -222,10 +222,10 @@ vino_server_handle_client_gone (rfbClientPtr rfb_client)
 	  g_io_channel_unref (client->io_channel);
 	  client->io_channel = NULL;
 
-	  g_free (l->data);
 	  server->priv->clients = g_slist_delete_link (server->priv->clients, l);
 
           vino_server_client_disconnected (server, client);
+	  g_free (client);
 
 	  break;
 	}
@@ -360,7 +360,10 @@ vino_server_handle_new_client (rfbClientPtr rfb_client)
   dprintf (RFB, "New client on fd %d\n", rfb_client->sock);
 
   if (!server->priv->fb)
-    vino_server_setup_framebuffer (server);
+    {
+      vino_server_setup_framebuffer (server);
+      rfb_client->format = server->priv->rfb_screen->rfbServerFormat;
+    }
 
   client = g_new0 (VinoClient, 1);
 
