@@ -97,7 +97,12 @@ VinoAuthMethod       vino_server_get_auth_methods         (VinoServer     *serve
 void                 vino_server_set_vnc_password         (VinoServer     *server,
 							   const char     *vnc_password);
 G_CONST_RETURN char *vino_server_get_vnc_password         (VinoServer     *server);
+void                 vino_server_set_lock_screen          (VinoServer     *server,
+							   gboolean        lock_screen);
+gboolean             vino_server_get_lock_screen          (VinoServer     *server);
 
+#include "vino-status-icon.h"
+VinoStatusIcon      *vino_server_get_status_icon          (VinoServer     *server);
 
 G_CONST_RETURN char *vino_client_get_hostname (VinoClient *client);
 void                 vino_client_disconnect   (VinoClient *client);
